#### INPUTS
#comm : observed (sampled) assemblages matrix = a species presence-absence matrix with sampled assemblages as row names and species as column names.
#nreps : number of repetitions of the null sampling

#### OUTPUT
# a dataframe listing for each pair of assemblages the effect size (ES) of similarity values

nreps<-999 #999 repetitions of the null sampling

# Observed community and sample sizes
gamm<- length(colSums(comm)>0)  #Total number of sampled species 
occur <- colSums(comm)/sum(comm) # Mean relative occurrence of sampled species within the regional species pool considered
n_ass <- nrow(comm) #Number of assemblages
n_pairs<-n_ass*(n_ass-1)/2 #Number of assemblage pairs 

# Species richness of each assemblage in comm :
alphas <- rowSums(ceiling(comm))
min(alphas) #Minimum species richness 
max(alphas) #Maximum species richness
mean(alphas) #Mean species richness


# Observed Sorensen value between each pair of (sampled) assemblages in comm:
library(ade4) #nequire for Sorensen calculation
obs_Sorensen<-dist.binary(comm, method=5) #Ade4 package computes distances (d) as sqrt(1-s), s = similarity index
obs_Sorensen_Corr<- ((-(obs_Sorensen)^2)+1) #So we applied the following transformation s = ((-d^2) +1), in order to convert distances (d) into a similarity index (s)
obs_Sorensen_Corr_mat<-matrix(obs_Sorensen_Corr)
obs_Sorensen_Corr_mat

#Creating the expected Sorensen value (between each pair of null assemblages matrix to be filled:
result_sorensen<-matrix(NA,ncol=nreps, nrow=n_pairs)
result_sorensen_es<-matrix(NA, ncol=nreps, nrow=n_pairs+1)

# looping on the n reps  
for (a in 1:nreps)  {  
  
  
	# Creating the null assemblages matrix to be filled :
	com2 <- matrix(ncol=gamm, nrow=n_ass)  
	colnames(com2) <- colnames(comm)
	rownames(com2) <- rownames(comm) 
	  

	# Null sampling : looping on the n_ass 
	for (k in 1:n_ass) {
    
		# Creating the null assemblage vector to be filled :
		com <- rep(0,gamm)  
    
		# random draw of the species present in the assemblage
		com[sample(1:gamm, alphas[k], replace=FALSE, prob=occur)]<-1    #prob = occur : The probability of each species to be selected in the random assemblages was weighted by the occurrence of the species within the regional species pool considered.
		com2[k,] <- com 
		
		}
  
# Expected Sorensen value between each pair of null assemblages 

	
	null_Sorensen<-dist.binary(com2, method=5)
	null_Sorensen_Corr<- ((-(null_Sorensen)^2)+1) #Transformation
	null_Sorensen_Corr_mat<-matrix(null_Sorensen_Corr)

	result_sorensen[,a]<-null_Sorensen_Corr
	result_sorensen
  
  
}

#Test for the normality of null distribution for each pair of assemblages
	#Creating the Shapiro test matrix to be filled
	result_shapiro<-matrix(NA,ncol=1, nrow=n_pairs)
	
	for (i in 1:n_pairs){ 
	if (!is.na(result_sorensen[i,1])){
	if (sum(result_sorensen[i,])!=0) {
	shapiro<-shapiro.test(result_sorensen[i,])
    shapiro$p.value
    result_shapiro[i,]=shapiro$p.value
  }}}
  summary(result_shapiro) # Due to the asymetry and non-Gaussian shape of the majority of null distribution we found in our data, we calculated an Effect Size (ES)


#Calculate the quantile of the null distribution for which the observed value is derived
	#Creating the "quantile" matrix to be filled:
	P.Sorensen_Corr.lower=matrix(NA,ncol=1, nrow=n_pairs)

	null_distribution=matrix(c(result_sorensen,obs_Sorensen_Corr_mat),nrow=n_pairs,ncol=nreps+1) #add the observed Sorensen value in the null distribution
	for (i in 1:n_pairs){ 
	P.Sorensen_Corr.lower[i,1]=(sum(as.numeric(null_distribution[i,]<obs_Sorensen_Corr_mat[i,])) + sum(as.numeric(null_distribution[i,]==obs_Sorensen_Corr_mat[i,]))/2)/(nreps+1)
	}
	
#Compute ES 
ES<- ((P.Sorensen_Corr.lower-0.5)*2)
ES

