library(nlme)
library(lmerTest)
library(lme4)
library(car)

####Input :
#data : A table containing 9 columns: 
	#ID:	Single ID of the two habitat patches constituting the pair of assemblages
	#ID1: Single ID of the first habitat patch constituting the pair of assemblages
	#ID2:	Single ID of the second habitat patch constituting the pair of assemblages
	#ES:	Effect size (ES) of similarity values
	#DistR_Woodlands:	Resistance distance of woodlands
	#DistR_Grasslands:Resistance distance of grasslands
	#DistR_Croplands: Resistance distance of croplands
	#SE_Moisture: Similarity edaphic indicator values of moisture for the pair of assemblages
	#SE_Nutrient: Similarity edaphic indicator values of nutrient avaibility for the pair of assemblages
	#SE_pH: 	  Similarity edaphic indicator values of pH for the pair of assemblages



# Consider ID as factor
data$ID=as.factor(data$ID)
data$ID1=as.factor(data$ID1)
data$ID2=as.factor(data$ID2)

# Remove NA values
mydata=na.omit(data)


###### Centering - scaling fixed effects
#1. Resistance distance
mydata$DistR_Woodlands_Cr = (mydata$DistR_Woodlands-mean(mydata$DistR_Woodlands))/sqrt(var(mydata$DistR_Woodlands))
mydata$DistR_Woodlands_Cr
mydata$DistR_Grasslands_Cr = (mydata$DistR_Grasslands-mean(mydata$DistR_Grasslands))/sqrt(var(mydata$DistR_Grasslands))
mydata$DistR_Grasslands_Cr
mydata$DistR_Croplands_Cr = (mydata$DistR_Croplands-mean(mydata$DistR_Croplands))/sqrt(var(mydata$DistR_Croplands))
mydata$DistR_Croplands_Cr

#2. Similarity edaphic indicator values
mydata$SE_Moisture_Cr=(mydata$SE_Moisture-mean(mydata$SE_Moisture))/sqrt(var(mydata$SE_Moisture))
mydata$SE_Nutrient_Cr=(mydata$SE_Nutrient-mean(mydata$SE_Nutrient))/sqrt(var(mydata$SE_Nutrient))
mydata$SE_pH_Cr=(mydata$SE_pH-mean(mydata$SE_pH))/sqrt(var(mydata$SE_pH))


######################################################################################
#####Influence of landscape connectivity on effect size (ES) of similarity value#####
######################################################################################
#Null model : model without any independent variable(s)
nullmod=lmer(mydata$ES~(1|mydata$ID1) + (1|mydata$ID2), REML=T)

#Backward stepwise selection procedure for selecting explanatory variables based on AIC
step(lm(ES~DistR_Woodlands_Cr+DistR_Grasslands_Cr+DistR_Croplands_Cr, data=mydata))

#Compute models with ?AIC = 2 units of the model with the lowest AIC (most parsimonius models) with the following syntax (example):

modpar=lmer(mydata$ES~mydata$DistR_Woodlands_Cr+mydata$DistR_Croplands_Cr + (1|mydata$ID1) + (1|mydata$ID2),  REML=T)
anova(modpar, nullmod) #p-value of the model(likelihood ratio test)
Anova(modpar, type="II") #p-value of each independent variable 
summary(modpar)#Estimate and ? of each independent variable
rsquared(modpar) #Rm and Rc of the model

##########################################################################################################################################################################
#####Influence of i) landscape connectivity and ii) similarity edaphic indicator values (moisture, nutrient avaibility and pH)on effect size (ES) of similarity value#####
##########################################################################################################################################################################
#Null model : model without any independent variable(s)
nullmod2=lmer(mydata$ES~(1|mydata$ID1) + (1|mydata$ID2), REML=T)

#Backward stepwise selection procedure for selecting explanatory variables based on AIC
step(lm(ES~DistR_Woodlands_Cr + DistR_Grasslands_Cr + DistR_Croplands_Cr + SE_Nutrient_Cr + SE_Moisture_Cr + SE_pH_Cr, data=mydata))

#Compute models with ?AIC = 2 units of the model with the lowest AIC (most parsimonius models) with the following syntax (example):
modpar2=lmer(mydata$ES~mydata$DistR_Woodlands_Cr+mydata$DistR_Croplands_Cr + SE_Moisture_Cr + SE_pH_Cr +(1|mydata$ID1) + (1|mydata$ID2),  REML=T)
anova(modpar2, nullmod2) #p-value of the model(likelihood ratio test)
Anova(modpar2, type="II") #p-value of each independent variable 
summary(modpar2)#Estimate and ? of each independent variable
rsquared(modpar2) #Rm and Rc of the model

